import { FC } from 'react';
import { ClassName } from '../hooks/className';
interface BaseFormFieldProps {
    name: string;
    title: string[];
    required: boolean;
    locked: boolean;
    error?: string;
    description?: string;
    displayMode?: 'default' | 'inline';
    className?: ClassName;
    onChange?: () => void;
}
export type FormFieldProps = FormFieldInputProps | FormFieldBooleanProps | FormFieldFileProps | FormFieldSelectProps | FormFieldSelectSearchProps;
interface FormFieldInputProps extends BaseFormFieldProps {
    type: 'FormFieldInput';
    htmlType?: 'text' | 'date' | 'datetime-local' | 'time' | 'email' | 'url' | 'number' | 'password';
    initial?: string | number;
    placeholder?: string;
}
export declare const FormFieldInputComp: FC<FormFieldInputProps>;
interface FormFieldBooleanProps extends BaseFormFieldProps {
    type: 'FormFieldBoolean';
    mode: 'checkbox' | 'switch';
    initial?: boolean;
}
export declare const FormFieldBooleanComp: FC<FormFieldBooleanProps>;
interface FormFieldFileProps extends BaseFormFieldProps {
    type: 'FormFieldFile';
    multiple?: boolean;
    accept?: string;
}
export declare const FormFieldFileComp: FC<FormFieldFileProps>;
interface SelectOption {
    value: string;
    label: string;
}
interface SelectGroup {
    label: string;
    options: SelectOption[];
}
type SelectOptions = SelectOption[] | SelectGroup[];
interface FormFieldSelectProps extends BaseFormFieldProps {
    type: 'FormFieldSelect';
    options: SelectOptions;
    initial?: string;
    multiple?: boolean;
    vanilla?: boolean;
    placeholder?: string;
}
export declare const FormFieldSelectComp: FC<FormFieldSelectProps>;
export declare const FormFieldSelectVanillaComp: FC<FormFieldSelectProps>;
export declare const FormFieldSelectReactComp: FC<FormFieldSelectProps>;
interface FormFieldSelectSearchProps extends BaseFormFieldProps {
    type: 'FormFieldSelectSearch';
    searchUrl: string;
    debounce?: number;
    initial?: SelectOption;
    multiple?: boolean;
    placeholder?: string;
}
export declare const FormFieldSelectSearchComp: FC<FormFieldSelectSearchProps>;
export {};
